@@ -27,6 +27,7 @@ class command:
 
     def __call__(self, f):
         name = self.name or f.__name__
+        f._iron_cmdname = name
         _command_registry[name] = f
         return f
 
@@ -48,5 +49,5 @@ class watch:
             pat = []
         elif isinstance(pat, str):
             pat = [pat]
-        _watch_rules.add((f.__name__, tuple(path), tuple(pat)))
+        _watch_rules.add((f._iron_cmdname, tuple(path), tuple(pat)))
         return f
