@@ -15,5 +15,5 @@ def write_to_file(dest, input_stream):
     with Path(dest).open('wb') as f:
         for chunk in input_stream:
             if not isinstance(chunk, bytes):
-                raise TypeError('bytes expected in input stream, got {}'.format(type(chunk)))
+                raise TypeError('bytes expected in input stream, got {}:'.format(type(chunk)))
             f.write(chunk)
