@@ -34,13 +34,16 @@ class ng_min(Task):
 
 
 class ng_template_cache(Task):
-    def __init__(self, target, module):
+    def __init__(self, target, module, create_module=False):
         self.module = module
         self.target = Path(target)
+        self.create_module = create_module
 
     def lazy_template_cache(self, inputs):
         yield b'angular.module('
         yield json.dumps(self.module).encode('utf-8')
+        if self.create_module:
+            yield b', []'
         yield b').run(["$templateCache", function ($templateCache) {\n\n'
 
         for t, c, _ in inputs:
