@@ -1,3 +1,5 @@
+import humanize
+import os
 import pprint
 from itertools import tee
 
@@ -184,8 +186,11 @@ class write(Task):
             else:
                 c1, c2 = tee(c)
             write_to_file(concrete_path, c1)
+            stat_info = os.stat(str(concrete_path))
+            num_bytes = stat_info.st_size
+            num_bytes = humanize.naturalsize(num_bytes)
             if not self.silent:
-                echo(style(str(concrete_path), fg='green') + ' written')
+                echo(style(str(concrete_path), fg='green') + ' written (' + style(num_bytes, fg='magenta') + ')')
             else:
-                self.log(str(concrete_path) + ' written')
+                self.log(str(concrete_path) + ' written (' + num_bytes + ')')
             yield t, c2, m
