@@ -17,6 +17,6 @@ class gzip(Task):
         yield gzip_buffer.getvalue()
 
     def process(self, inputs):
-        for t, c in inputs:
+        for t, c, m in inputs:
             t2 = t.with_name(t.name + '.gz')
-            yield t2, self.lazy_gzip(c)
+            yield t2, self.lazy_gzip(c), m
