@@ -41,6 +41,20 @@ class ExternalCommand:
             self.stderr = stderr
 
 
+class babel(ExternalCommandTask):
+    """
+    Transpiles ES-next to ES-today.
+
+    Available options are modeled after the command line options for the
+    ``babel`` command line tool.
+    """
+
+    def process(self, inputs):
+        cmd = ['babel']
+        for t, c, m in inputs:
+            yield t, [self.run_external(cmd, input=b''.join(c))], m
+
+
 class coffee(ExternalCommandTask):
     """Compile Coffeescript to JavaScript."""
 
