@@ -3,8 +3,6 @@ import time
 
 from click import echo
 
-from pathlib import Path
-
 from .commands import run_commands
 
 
@@ -17,38 +15,22 @@ def watch_forever(env, verbose):
     command.
     """
     try:
-        from watchdog.events import FileSystemEventHandler
+        from watchdog.events import PatternMatchingEventHandler
         from watchdog.observers import Observer
     except ImportError:
         echo('The watcher requires watchdog to be installed.')
         sys.exit(3)
 
-    class CommandTrigger(FileSystemEventHandler):
+    class CommandTrigger(PatternMatchingEventHandler):
         def __init__(self, patterns, cmdname, env, verbose):
-            self.patterns = patterns
+            super().__init__(patterns=patterns, ignore_patterns=['.DS_Store'], ignore_directories=True)
             self.cmdname = cmdname
             self.env = env
             self.verbose = verbose
 
         def on_any_event(self, event):
-            # Ignore directories
-            if event.is_directory:
-                return
-
-            # Ignore .DS_Store updates
-            src_path = Path(event.src_path)
-            if src_path.name == '.DS_Store':
-                if self.verbose:
-                    echo('Ignoring changes to .DS_Store')
-                return
-
-            # Must match pattern
-            if not self.patterns or any(src_path.match(pat) for pat in self.patterns):
-                echo('>>> Running {}'.format(self.cmdname))
-                run_commands([self.cmdname], self.env, self.verbose)
-            else:
-                if self.verbose:
-                    echo('Ignoring {} (does not match any of {})'.format(src_path, self.patterns))
+            echo('>>> Running {}'.format(self.cmdname))
+            run_commands([self.cmdname], self.env, self.verbose)
 
     observer = Observer(timeout=1.7)
 
